==> ejc-middlemeasurement-impl-3.0.0-20221024.101540-187-sources.jar: com/ejianc/business/middlemeasurement/vo/ConsultotherodetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 咨询及其他类合同过程结算单-其他扣款
 *
 * @author generator
 *
 */
public class ConsultotherodetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mid; // 主表id
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String sort; // 序号
    private String expenseName; // 费用名称
    private String unit; // 单位
    private java.math.BigDecimal oQuantity; // 数量
    private java.math.BigDecimal oUnitPrice; // 单价
    private java.math.BigDecimal amounts; // 金额
    private String remarks; // 备注
    private String errorMsg; // 导入错误信息


    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }
}

==> ejc-middlemeasurement-impl-3.0.0-20230215.084947-351-sources.jar: com/ejianc/business/middlemeasurement/vo/ConsultotherodetailVO.java <==
package com.ejianc.business.middlemeasurement.vo;

import java.math.BigDecimal;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 咨询及其他类合同过程结算单-其他扣款
 *
 * @author generator
 *
 */
public class ConsultotherodetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long mid; // 主表id
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String sort; // 序号
    private String expenseName; // 费用名称
    private String unit; // 单位
    private java.math.BigDecimal oQuantity; // 数量
    private java.math.BigDecimal oUnitPrice; // 单价
    private java.math.BigDecimal amounts; // 金额
    private String remarks; // 备注
    private String errorMsg; // 导入错误信息
    private java.math.BigDecimal oTaxUnitPrice; // (含税)单价
    private java.math.BigDecimal taxAmounts; // (含税)金额

    /**
     * 主表id
     */
    public Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    /**
     * 序号
     */
    public String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(String sort) {
        this.sort = sort;
    }
    /**
     * 费用名称
     */
    public String getExpenseName() {
        return expenseName;
    }

    /**
     * 费用名称
     */
    public void setExpenseName(String expenseName) {
        this.expenseName = expenseName;
    }
    /**
     * 单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }

    /**
     * 金额
     */
    public java.math.BigDecimal getAmounts() {
        return amounts;
    }

    /**
     * 金额
     */
    public void setAmounts(java.math.BigDecimal amounts) {
        this.amounts = amounts;
    }
    /**
     * 备注
     */
    public String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public BigDecimal getoQuantity() {
        return oQuantity;
    }

    public void setoQuantity(BigDecimal oQuantity) {
        this.oQuantity = oQuantity;
    }

    public BigDecimal getoUnitPrice() {
        return oUnitPrice;
    }

    public void setoUnitPrice(BigDecimal oUnitPrice) {
        this.oUnitPrice = oUnitPrice;
    }

    public BigDecimal getoTaxUnitPrice() {
        return oTaxUnitPrice;
    }

    public void setoTaxUnitPrice(BigDecimal oTaxUnitPrice) {
        this.oTaxUnitPrice = oTaxUnitPrice;
    }

    public BigDecimal getTaxAmounts() {
        return taxAmounts;
    }

    public void setTaxAmounts(BigDecimal taxAmounts) {
        this.taxAmounts = taxAmounts;
    }
}
